================================================================
Workflow Templates for Reproducible for Data Analysis Benchmarks
================================================================

.. image:: https://api.travis-ci.org/scailfin/benchmark-templates.svg?branch=master
   :target: https://travis-ci.org/scailfin/benchmark-templates?branch=master

.. image:: https://coveralls.io/repos/github/scailfin/benchmark-templates/badge.svg?branch=master
   :target: https://coveralls.io/github/scailfin/benchmark-templates?branch=master

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://github.com/scailfin/benchmark-templates/blob/master/LICENSE



About
=====

**Workflow Templates** are parameterized workflow specifications for the *Reproducible Open Benchmarks for Data Analysis Platform (ROB)*. Workflow templates are motivated by the goal to allow users to run pre-defined data analytics workflows while providing their own input data, parameters, as well as their own code modules. Workflow templates are inspired by, but not limited to, workflow specifications for the `Reproducible Research Data Analysis Platform (REANA) <http://www.reanahub.io/>`_.


More Information
================

The `Workflow Templates Section <https://github.com/scailfin/benchmark-templates/blob/master/docs/workflow.rst>`_ provides further information about templates and their syntax. `Benchmark Templates <https://github.com/scailfin/benchmark-templates/blob/master/docs/benchmark.rst>`_ are an extension of the base templates. These templates are used by the `Reproducible Benchmark Engine <https://github.com/scailfin/benchmark-engine>`_ to run benchmark workflows and maintain benchmark results.
